==> nextcloud-29.0.7.tar.bz2: nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação da CPU não disponível",
    "Load average: {cpu} (last minute)" : "Média de carga: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes} / Uso atual: {memUsageBytes}",
    "RAM info not available" : "Informação de RAM não disponível",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes} / Uso atual: {swapUsageBytes}",
    "SWAP info not available" : "Informação SWAP não disponível",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoramento",
    "Monitoring app with useful server information" : "Aplicativo de monitoramento com informações úteis do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "Operating System:" : "Sistema Operacional:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Processador Desconhecido",
    "Memory:" : "Memoria:",
    "Server time:" : "Horário do servidor:",
    "Uptime:" : "Tempo de atividade:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memória",
    "Disk" : "Disco",
    "Mount:" : "Montagem:",
    "Filesystem:" : "Sistema de arquivo:",
    "Size:" : "Tamanho:",
    "Available:" : "Disponível:",
    "Used:" : "Usado:",
    "Files:" : "Arquivos:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço livre:",
    "Network" : "Rede",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Velocidade:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuários ativos",
    "Total users:" : "Total de usuários:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 mins:",
    "Shares" : "Compartilhamentos",
    "Users:" : "Usuários:",
    "Groups:" : "Grupos:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federado enviado:",
    "Federated received:" : "Federado recebeu:",
    "Talk conversations:" : "Conversas do Talk:",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Memory limit:" : "Limite de memória:",
    "Max execution time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "OPcache Revalidate Frequency:" : "Frequência de revalidação do OPcache:",
    "Extensions:" : "Extensões:",
    "Unable to list extensions" : "Não foi possível listar as extensões",
    "Show phpinfo" : "Mostrar phpinfo",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "Use this end point to connect an external monitoring tool:" : "Use este ponto final para conectar uma ferramenta de monitoramento externa:",
    "Copy" : "Copiar",
    "Output in JSON" : "Saída em JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Ignorar seção de aplicativos (incluindo a seção de aplicativos enviará uma solicitação externa para a loja de aplicativos)",
    "Skip server update" : "Ignorar atualização do servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar um token de acesso, gere um e defina-o usando o seguinte comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Em seguida, passe o token com o cabeçalho \"NC-Token\" ao consultar o URL acima.",
    "DNS:" : "DNS:"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.9.tar.bz2: nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informação da CPU não disponível",
    "Load average: {cpu} (last minute)" : "Média de carga: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes} / Uso atual: {memUsageBytes}",
    "RAM info not available" : "Informação de RAM não disponível",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes} / Uso atual: {swapUsageBytes}",
    "SWAP info not available" : "Informação SWAP não disponível",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitoramento",
    "Monitoring app with useful server information" : "Aplicativo de monitoramento com informações úteis do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "Operating System:" : "Sistema Operacional:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Processador Desconhecido",
    "Memory:" : "Memoria:",
    "Server time:" : "Horário do servidor:",
    "Uptime:" : "Tempo de atividade:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memória",
    "Disk" : "Disco",
    "Mount:" : "Montagem:",
    "Filesystem:" : "Sistema de arquivo:",
    "Size:" : "Tamanho:",
    "Available:" : "Disponível:",
    "Used:" : "Usado:",
    "Files:" : "Arquivos:",
    "Storages:" : "Armazenamentos:",
    "Free Space:" : "Espaço livre:",
    "Network" : "Rede",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Velocidade:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuários ativos",
    "Last hour" : "Última hora",
    "%s%% of all users" : "%s%% de todos os usuários",
    "Last 24 Hours" : "Últimas 24 Horas",
    "Last 7 Days" : "Últimos 7 Dias",
    "Last 30 Days" : "Últimos 30 Dias",
    "Shares" : "Compartilhamentos",
    "Users:" : "Usuários:",
    "Groups:" : "Grupos:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federado enviado:",
    "Federated received:" : "Federado recebeu:",
    "Talk conversations:" : "Conversas do Talk:",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Memory limit:" : "Limite de memória:",
    "Max execution time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "OPcache Revalidate Frequency:" : "Frequência de revalidação do OPcache:",
    "Extensions:" : "Extensões:",
    "Unable to list extensions" : "Não foi possível listar as extensões",
    "Show phpinfo" : "Mostrar phpinfo",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "Use this end point to connect an external monitoring tool:" : "Use este ponto final para conectar uma ferramenta de monitoramento externa:",
    "Copy" : "Copiar",
    "Output in JSON" : "Saída em JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Ignorar seção de aplicativos (incluindo a seção de aplicativos enviará uma solicitação externa para a loja de aplicativos)",
    "Skip server update" : "Ignorar atualização do servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar um token de acesso, gere um e defina-o usando o seguinte comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Em seguida, passe o token com o cabeçalho \"NC-Token\" ao consultar o URL acima.",
    "DNS:" : "DNS:",
    "Total users:" : "Total de usuários:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 mins:"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
